==> StorageGRID-11.9.0.8-Sources-FTP.tar.gz: corretto-8-8.392.08.1/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

Thank you for taking the time to help improve OpenJDK and Corretto.

If your request concerns a security vulnerability then please report it by email to aws-security@amazon.com instead of here. (You can find more information regarding security issues at https://aws.amazon.com/security/vulnerability-reporting/.)

Otherwise, if your issue concerns OpenJDK 8 and is not specific to Corretto 8 we ask that you raise it to the OpenJDK community. Depending on your contributor status for OpenJDK, please use the [JDK bug system]() or the appropriate [mailing list](http://mail.openjdk.java.net/mailman/listinfo) for the given problem area or update project [jdk8u-dev](http://mail.openjdk.java.net/mailman/listinfo/jdk8u-dev).

If your issue is specific to Corretto 8,
then you are in the right place.
Please proceed with the following.

### Describe the bug
A clear and concise description of what the bug is.

### To Reproduce
Steps and (source) code to reproduce the behavior.

### Expected behavior
A clear and concise description of what you expected to happen.

### Screenshots
If applicable, add screenshots to help explain your problem.

### Platform information
    OS: [e.g. Amazon Linux 2]
    Version [e.g. "build 1.8.0_192-amazon-corretto-preview-b12" (output from "java -version")]

### Additional context
Add any other context about the problem here.

For VM crashes, please attach the error report file. By default the file name is `hs_err_pidpid.log`, where pid is the process ID of the process.

==> StorageGRID-12.0.0-Sources-FTP.tar.gz: corretto-17-17.0.13.11.1/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

Thank you for taking the time to help improve OpenJDK and Corretto.

If your request concerns a security vulnerability then please report it by email to aws-security@amazon.com instead of here. (You can find more information regarding security issues at https://aws.amazon.com/security/vulnerability-reporting/.)

Otherwise, if your issue concerns OpenJDK and is not specific to Corretto we ask that you raise it to the OpenJDK community. Depending on your contributor status for OpenJDK, please use the [JDK bug system](https://bugs.openjdk.java.net/) or the appropriate [mailing list](http://mail.openjdk.java.net/mailman/listinfo) for the given problem area or [update project](http://mail.openjdk.java.net/mailman/listinfo/jdk-updates-dev).

If your issue is specific to Corretto, then you are in the right place. Please proceed with the following.

### Describe the bug
A clear and concise description of what the bug is.

### To Reproduce
Steps and (source) code to reproduce the behavior.

### Expected behavior
A clear and concise description of what you expected to happen.

### Screenshots
If applicable, add screenshots to help explain your problem.

### Platform information
    OS: [e.g. Amazon Linux 2]
    Version [e.g. "Corretto-15.0.1.9.1" (output from "java -version")]

### Additional context
Add any other context about the problem here.

For VM crashes, please attach the error report file. By default the file name is `hs_err_pidpid.log`, where pid is the process ID of the process.
